==> abg_utils-4.2.1.tar.gz: lib/src/model/cart.dart <==

import '../../abg_utils.dart';

List<ProductData> cart = [];
ProviderData? currentProvider;

String? addToCart(ProductData service,
    String stringAlreadyInCart  /// strings.get(210) /// This service already in the cart
    ){
  for (var item in cart)
    if (item.id == service.id)
      return stringAlreadyInCart;
  cart.add(service);
  _cartSave();
}

removeFromCart(ProductData service){
  for (var item in cart)
    if (item.id == service.id){
      cart.remove(item);
      _cartSave();
      return;
    }
}

_cartSave(){
  //userAccountData.cartList = [];
  // for (var item in cart)
  //   userAccountData.cartList.add(item.id);
  // User? user = FirebaseAuth.instance.currentUser;
  // if (user == null)
  //   return "user == null";
  // FirebaseFirestore.instance.collection("listusers").doc(user.uid).set({
  //   "cartList": userAccountData.cartList,
  // }, SetOptions(merge:true));
  // redrawMainWindow();
}

initCart(){
  // lastBookingId = "";
  // if (_init)
  //   return;
  // _init = true;
  // for (var providerId in userAccountData.cartList){
  //   for (var service in product)
  //     if (service.id == providerId) {
  //       bool _found = false;
  //       for (var item in cart )
  //         if (item.id == service.id)
  //           _found = true;
  //       if (!_found)
  //         cart.add(service);
  //     }
  // }
}

_removeCheckoutFromCart(){
  for (var item in userAccountData.cartList)
    for (var service in cart)
      if (service.id == item){
        cart.remove(service);
        break;
      }
  _cartSave();
}

// _allCheckout(){
//   checkout = [];
//   for (var item in cart)
//     if (item.providers.isNotEmpty)
//       checkout.add(item.providers[0]);
// }



checkoutProvider(ProviderData provider){
  // currentProvider = provider;
  // checkout = [];
  // for (var item in cart)
  //   if (item.providers.isNotEmpty)
  //     if (item.providers[0] == provider.id)
  //       checkout.add(item.providers[0]);
}

clearCart(){
  // checkout = [];
  // couponCode = "";
  // coupon = null;
  // cachePayment = true;
  // hint = "";
  // anyTime = true;
  // selectTime = DateTime.now();
  // paymentMethod = 1;
}

Future<String?> finish(String paymentMethod) async{
  // for (var item in userAccountData.cartList){
  //   for (var service in cart){
  //     if (service.id == item) {
  //       var ret = await _finish(_mainModel, service, paymentMethod);
  //       if (ret != null)
  //         messageError(parent.context, ret);
  //     }
  //   }
  // }
  // _removeCheckoutFromCart();
  // clearCart();
}

List<String> _cartGetProviders(){
  List<String> ret = [];
  for (var item in cart)
    if (item.providers.isNotEmpty)
      if (!ret.contains(item.providers[0]))
        ret.addAll(item.providers);
  return ret;
}

List<ProviderData> cartGetProvidersData(){
  List<ProviderData> ret = [];
  List<String> list = _cartGetProviders();
  for (var item in list){
    var t = getProviderById(item);
    if (t != null)
      ret.add(t);
  }
  return ret;
}

==> abg_utils-4.2.2.tar.gz: lib/src/model/cart.dart <==

import '../../abg_utils.dart';

List<ProductData> cart = [];
ProviderData? cartCurrentProvider;
bool cartAnyTime = true;
var cartSelectTime = DateTime.now();
String cartHint = "";
String cartCouponCode = "";
/*
вся информация в price.dart:
String couponId = "";     // 2746fde7643fgd
String couponCode = "";   // CODE25
String discountType = ""; // "percent" or "fixed"
double discount = 0;      // 12
 */

clearCart(){
  // checkout = [];
  cartCouponCode = "";
  // coupon = null;
  // cachePayment = true;
  cartHint = "";
  cartAnyTime = true;
  cartSelectTime = DateTime.now();
  // paymentMethod = 1;
}

// List<String> checkout = []; // provider id

String? addToCart(ProductData service,
    String stringAlreadyInCart  /// strings.get(210) /// This service already in the cart
    ){
  for (var item in cart)
    if (item.id == service.id)
      return stringAlreadyInCart;
  cart.add(service);
  _cartSave();
}

removeFromCart(ProductData service){
  for (var item in cart)
    if (item.id == service.id){
      cart.remove(item);
      _cartSave();
      return;
    }
}

_cartSave(){
  //userAccountData.cartList = [];
  // for (var item in cart)
  //   userAccountData.cartList.add(item.id);
  // User? user = FirebaseAuth.instance.currentUser;
  // if (user == null)
  //   return "user == null";
  // FirebaseFirestore.instance.collection("listusers").doc(user.uid).set({
  //   "cartList": userAccountData.cartList,
  // }, SetOptions(merge:true));
  // redrawMainWindow();
}

initCart(){
  // lastBookingId = "";
  // if (_init)
  //   return;
  // _init = true;
  // for (var providerId in userAccountData.cartList){
  //   for (var service in product)
  //     if (service.id == providerId) {
  //       bool _found = false;
  //       for (var item in cart )
  //         if (item.id == service.id)
  //           _found = true;
  //       if (!_found)
  //         cart.add(service);
  //     }
  // }
}

_removeCheckoutFromCart(){
  for (var item in userAccountData.cartList)
    for (var service in cart)
      if (service.id == item){
        cart.remove(service);
        break;
      }
  _cartSave();
}

// _allCheckout(){
//   checkout = [];
//   for (var item in cart)
//     if (item.providers.isNotEmpty)
//       checkout.add(item.providers[0]);
// }

checkoutProvider(ProviderData provider){
  cartCurrentProvider = provider;
  // checkout = [];
  // for (var item in cart)
  //   if (item.providers.isNotEmpty)
  //     if (item.providers[0] == provider.id)
  //       checkout.add(item.providers[0]);
}


Future<String?> finish(String paymentMethod) async{
  // for (var item in userAccountData.cartList){
  //   for (var service in cart){
  //     if (service.id == item) {
  //       var ret = await _finish(_mainModel, service, paymentMethod);
  //       if (ret != null)
  //         messageError(parent.context, ret);
  //     }
  //   }
  // }
  // _removeCheckoutFromCart();
  // clearCart();
}

List<String> _cartGetProviders(){
  List<String> ret = [];
  for (var item in cart)
    if (item.providers.isNotEmpty)
      if (!ret.contains(item.providers[0]))
        ret.addAll(item.providers);
  return ret;
}

List<ProviderData> cartGetProvidersData(){
  List<ProviderData> ret = [];
  List<String> list = _cartGetProviders();
  for (var item in list){
    var t = getProviderById(item);
    if (t != null)
      ret.add(t);
  }
  return ret;
}
